@@ -4,10 +4,11 @@ from datetime import datetime
 import logging
 from typing import Any, Optional, Union, Dict
 
+import pickledb
 from web3 import Web3
 from web3.eth import Contract
 from web3.contract import ContractFunction
-from web3.exceptions import ContractLogicError
+from web3.exceptions import ContractLogicError, TimeExhausted
 from web3.middleware import geth_poa_middleware
 from web3.types import (
     TxParams,
@@ -17,7 +18,7 @@ from web3.types import (
 )
 from polysynth.enum import ErrorMessage, PnlCalcOption, StatusCode
 
-from polysynth.exception import InvalidParameterError, MissingInputError, PolysynthException, TransactionFailedError
+from polysynth.exception import InvalidParameterError, MissingInputError, PolysynthException, TransactionFailedError, NoPositionsOpen, TransactionTimedOut
 from .types import AddressLike, FundingRateRes, MarginRes, OpenPositionRes, Response, TraderPosition
 from .util import (
     _str_to_addr,
@@ -109,6 +110,8 @@ class Polysynth:
             self.max_approval_check_int = int(self.max_approval_check_hex, 16)
 
             self.fluctuation_limit = 0.012
+            self.tx_timeout = 30
+            self.db = pickledb.load('txns.db', False)
 
             if self.version == 1:
                 if stable_token_contract_addr is None:
@@ -165,9 +168,9 @@ class Polysynth:
         '''
         try:
             price = _normalize(self._input_price(amm, side, quoteAssetAmount)[0])
-            return Response(StatusCode.OK.value, None, None, data= {"amount": abs(price) })
+            return Response(StatusCode.OK.value, None, None, data= {"amount": abs(price) }).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
     
     def output_price(
         self,
@@ -198,9 +201,9 @@ class Polysynth:
                 _side_str_to_int(side),
                 _int_to_bignum(baseAssetAmount)
             ).call()
-            return Response(StatusCode.OK.value, None, None, data= { "amount": abs(_normalize(price[0])) })
+            return Response(StatusCode.OK.value, None, None, data= { "amount": abs(_normalize(price[0])) }).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def open_position(
         self,
@@ -247,11 +250,23 @@ class Polysynth:
 
             func = manager.openPosition(*func_params)
             receipt = self._build_and_send_tx(func, tx_params)
-            tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=1000)
+            tx = None
+            try:
+                tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+            except TimeExhausted as te:
+                self.db.set(receipt.hex(), ("openPosition", func_params, tx_params["nonce"]))
+                self.db.dump()
+                return TransactionTimedOut(
+                    StatusCode.REQUEST_TIMEOUT.value,
+                    StatusCode.TRANSACTION_PENDING.value,
+                    ErrorMessage.TRANSACTION_PENDING.value,
+                    data = {"tx_hash": receipt.hex()}).__dict__()
 
             time.sleep(2)
 
             position = self._trader_position(amm)
+            if position[0] == 0:
+                raise NoPositionsOpen(StatusCode.OK.value, StatusCode.ZERO_COLLATERAL.value, ErrorMessage.NO_POSITIONS_OPEN.value)
             _price = round(position[2]/position[0], 4)
             _size = _normalize(position[0])
             _side = "BUY" if _size > 0 else "SELL"
@@ -261,9 +276,9 @@ class Polysynth:
 
             result = OpenPositionRes(_price, _side, _size, _leverage, _collateral_ratio, tx).__dict__()
 
-            return Response(StatusCode.OK.value, None, None, data=result)
+            return Response(StatusCode.OK.value, None, None, data=result).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def close_position(
         self,
@@ -287,7 +302,7 @@ class Polysynth:
             _position = self._trader_position(amm)
             _size = _normalize(_position[0])
             if _size == 0:
-                raise TransactionFailedError(StatusCode.FAILED_TRASACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value)
+                raise TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value)
 
             amm_contract_addr = _amm_name_to_addr(amm, self.network) # for eg resolves to Amm_eth
 
@@ -302,16 +317,26 @@ class Polysynth:
 
             func = manager.closePosition(*func_params)
             receipt = self._build_and_send_tx(func, tx_params)
-            tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=1000)
+            tx = None
+            try:
+                tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+            except TimeExhausted as te:
+                self.db.set(receipt.hex(), ("closePosition", func_params, tx_params["nonce"]))
+                self.db.dump()
+                return TransactionTimedOut(
+                    StatusCode.REQUEST_TIMEOUT.value,
+                    StatusCode.TRANSACTION_PENDING.value,
+                    ErrorMessage.TRANSACTION_PENDING.value,
+                    data = {"tx_hash": receipt.hex()}).__dict__()
 
             result = {
                 "tx_hash": tx["transactionHash"].hex(),
                 "gas_fees": tx["gasUsed"],
             }
 
-            return Response(StatusCode.OK.value, None, None, data=result)
+            return Response(StatusCode.OK.value, None, None, data=result).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
     
     def add_margin(
         self,
@@ -338,7 +363,17 @@ class Polysynth:
             tx_params = self._get_tx_params()
             func = manager.addCollateral(*func_params)
             receipt = self._build_and_send_tx(func, tx_params)
-            tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=1000)
+            tx = None
+            try:
+                tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+            except TimeExhausted as te:
+                self.db.set(receipt.hex(), ("addCollateral", func_params, tx_params["nonce"]))
+                self.db.dump()
+                return TransactionTimedOut(
+                    StatusCode.REQUEST_TIMEOUT.value,
+                    StatusCode.TRANSACTION_PENDING.value,
+                    ErrorMessage.TRANSACTION_PENDING.value,
+                    data = {"tx_hash": receipt.hex()}).__dict__()
             time.sleep(1)
             # get trader's new leverage and margin
             position = self._trader_position_with_funding_payment(amm)
@@ -350,11 +385,11 @@ class Polysynth:
             ratio = _normalize(self._collateral_ratio(amm))
             result = MarginRes(_margin_after, new_leverage, ratio, tx).__dict__()
 
-            return Response(StatusCode.OK.value, None, None, data=result)
+            return Response(StatusCode.OK.value, None, None, data=result).__dict__()
         except ContractLogicError as e:
-            return TransactionFailedError(StatusCode.FAILED_TRASACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value)
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def remove_margin(
         self,
@@ -394,7 +429,17 @@ class Polysynth:
             tx_params = self._get_tx_params()
             func = manager.removeCollateral(*func_params)
             receipt = self._build_and_send_tx(func, tx_params)
-            tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=1000)
+            tx = None
+            try:
+                tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+            except TimeExhausted as te:
+                self.db.set(receipt.hex(), ("removeCollateral", func_params, tx_params["nonce"]))
+                self.db.dump()
+                return TransactionTimedOut(
+                    StatusCode.REQUEST_TIMEOUT.value,
+                    StatusCode.TRANSACTION_PENDING.value,
+                    ErrorMessage.TRANSACTION_PENDING.value,
+                    data = {"tx_hash": receipt.hex()}).__dict__()
 
             position = self._trader_position_with_funding_payment(amm)
             new_collateral, new_leverage = _normalize(position[1]), round(position[2]/position[1], 4)
@@ -404,11 +449,11 @@ class Polysynth:
 
             ratio = _normalize(self._collateral_ratio(amm))
             result = MarginRes(_margin_after, new_leverage, ratio, tx).__dict__()
-            return Response(StatusCode.OK.value, None, None, data=result)
+            return Response(StatusCode.OK.value, None, None, data=result).__dict__()
         except ContractLogicError as e:
-            return TransactionFailedError(StatusCode.FAILED_TRASACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value)
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
  
     def allowance(
         self,
@@ -434,9 +479,17 @@ class Polysynth:
         func = token.approve(*func_params)
         tx_params = self._get_tx_params()
         txid = self._build_and_send_tx(func, tx_params)
-        self.w3.eth.wait_for_transaction_receipt(txid, timeout=6000)
-
-        time.sleep(1)
+        tx = None
+        try:
+            tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+        except TimeExhausted as te:
+            self.db.set(receipt.hex(), (func, tx_params["nonce"]))
+            self.db.dump()
+            return TransactionTimedOut(
+                StatusCode.REQUEST_TIMEOUT.value,
+                StatusCode.TRANSACTION_PENDING.value,
+                ErrorMessage.TRANSACTION_PENDING.value,
+                data = {"tx_hash": receipt.hex()}).__dict__()
 
     def mark_price(
         self,
@@ -455,9 +508,9 @@ class Polysynth:
         '''
         try:
             price = _normalize(self._spot_price(amm))
-            return Response(StatusCode.OK.value, None, None, data= {"mark_price": price })
+            return Response(StatusCode.OK.value, None, None, data= {"mark_price": price }).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def fluctuation_limit_ratio(
         self,
@@ -485,9 +538,9 @@ class Polysynth:
                     address=_str_to_addr(amm_contract_addr),
                 )
             flr = amm_contract.functions.fluctuationLimitRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"fluctuation_limit_ratio": round(flr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"fluctuation_limit_ratio": round(flr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def trade_limit_ratio(
         self,
@@ -515,9 +568,9 @@ class Polysynth:
                     address=_str_to_addr(amm_contract_addr),
                 )
             tlr = amm_contract.functions.tradeLimitRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"trade_limit_ratio": round(tlr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"trade_limit_ratio": round(tlr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def margin_ratio(
         self,
@@ -536,11 +589,11 @@ class Polysynth:
         '''
         try:
             ratio = _normalize(self._collateral_ratio(amm))
-            return Response(StatusCode.OK.value, None, None, data= {"margin_ratio": ratio})
+            return Response(StatusCode.OK.value, None, None, data= {"margin_ratio": ratio}).__dict__()
         except ContractLogicError as e:
-            return TransactionFailedError(StatusCode.FAILED_TRASACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value)
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.EXECUTION_REVERTED.value, ErrorMessage.NO_POSITIONS_OPEN.value).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def fee_ratio(
         self,
@@ -557,9 +610,9 @@ class Polysynth:
         '''
         try:
             fr = self.manager_contract.functions.feeRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"fee_ratio": round(fr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"fee_ratio": round(fr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def init_margin_ratio(
         self,
@@ -576,9 +629,9 @@ class Polysynth:
         '''
         try:
             icr = self.manager_contract.functions.initCollateralRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"init_margin_ratio": round(icr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"init_margin_ratio": round(icr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def liquidation_fee_ratio(
         self,
@@ -595,9 +648,9 @@ class Polysynth:
         '''
         try:
             lfr = self.manager_contract.functions.liquidationFeeRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"liquidation_fee_ratio": round(lfr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"liquidation_fee_ratio": round(lfr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def maintenance_margin_ratio(
         self,
@@ -614,9 +667,9 @@ class Polysynth:
         '''
         try:
             mcr = self.manager_contract.functions.maintenanceCollateralRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"maintenance_margin_ratio": round(mcr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"maintenance_margin_ratio": round(mcr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def partial_liquidation_ratio(
         self,
@@ -633,9 +686,9 @@ class Polysynth:
         '''
         try:
             plr = self.manager_contract.functions.partialLiquidationRatio().call()
-            return Response(StatusCode.OK.value, None, None, data= {"partial_liquidation_ratio": round(plr/10**18, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"partial_liquidation_ratio": round(plr/10**18, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def price_impact(
         self,
@@ -657,9 +710,9 @@ class Polysynth:
             quoteAssetAmount = _normalize(self._output_price(amm, "BUY", size)[0])
 
             fluctuation = self._price_impact(amm, quoteAssetAmount, 1, 0)
-            return Response(StatusCode.OK.value, None, None, data= {"price_impact": round(fluctuation, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"price_impact": round(fluctuation, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def wallet_balance(
         self,
@@ -673,9 +726,9 @@ class Polysynth:
         '''
         try:
             balance = self._wallet_balance()
-            return Response(StatusCode.OK.value, None, None, data= {"wallet_balance": round(balance/10**6, 7)})
+            return Response(StatusCode.OK.value, None, None, data= {"wallet_balance": round(balance/10**6, 7)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
     
     def unrealized_pnl(
         self,
@@ -691,9 +744,9 @@ class Polysynth:
         '''
         try:
             unrealized_pnl = _normalize(self._unrealized_pnl(amm))
-            return Response(StatusCode.OK.value, None, None, data= {"unrealized_pnl": unrealized_pnl})
+            return Response(StatusCode.OK.value, None, None, data= {"unrealized_pnl": unrealized_pnl}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def positions(
         self,
@@ -731,9 +784,9 @@ class Polysynth:
 
                 result = TraderPosition(amm.upper(), side, size, collateral, leverage, avg_entry_price, margin, unrealized_pnl).__dict__()
                 res.append(result)
-            return Response(StatusCode.OK.value, None, None, data=res)
+            return Response(StatusCode.OK.value, None, None, data=res).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def index_price(
         self,
@@ -759,9 +812,9 @@ class Polysynth:
                     address=_str_to_addr(oracle_addr),
                 )
             price = oracle_contract.functions.latestRoundData().call()
-            return Response(StatusCode.OK.value, None, None, data= {"index_price": round(price[1]/10**8, 4)})
+            return Response(StatusCode.OK.value, None, None, data= {"index_price": round(price[1]/10**8, 4)}).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
 
     def funding_rate(
         self,
@@ -789,9 +842,95 @@ class Polysynth:
 
             futures = amm.upper()
             result = FundingRateRes(funding_rate_long, funding_rate_short, futures).__dict__()
-            return Response(StatusCode.OK.value, None, None, data= result)
+            return Response(StatusCode.OK.value, None, None, data= result).__dict__()
         except PolysynthException as e:
-            return e
+            return e.__dict__()
+
+    def cancel_transaction(self, tx_hash: Optional[str]=None) -> Any:
+        try:
+            if tx_hash:
+                try:
+                    receipt = self.w3.eth.get_transaction_receipt(tx_hash)
+                    data = { "tx_hash": receipt["transactionHash"].hex() }
+                    return Response(StatusCode.ALREADY_EXISTS.value, StatusCode.TRANSACTION_EXISTS.value, ErrorMessage.TRANSACTION_EXISTS.value, data=data).__dict__()
+                except Exception as e:
+                    pass
+
+            tx_params = self._get_cancel_tx_params()
+            receipt = None
+            signed_txn = self.w3.eth.account.sign_transaction(tx_params, private_key=self.private_key)
+
+            try:
+                receipt = self.w3.eth.send_raw_transaction(signed_txn.rawTransaction)
+            finally:
+                self.last_nonce = Nonce(tx_params["nonce"] + 1)
+
+            try:
+                tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+                result = {
+                    "tx_hash": tx["transactionHash"].hex(),
+                    "gas_fees": tx["gasUsed"],
+                    }
+                if self.db.exists(tx_hash):
+                    self.db.rem(tx_hash)
+                    self.db.dump() # delete the pending tx entry
+                return Response(StatusCode.OK.value, None, None, data=result).__dict__()
+            except TimeExhausted as te:
+                return TransactionTimedOut(
+                    StatusCode.REQUEST_TIMEOUT.value,
+                    StatusCode.TRANSACTION_PENDING.value,
+                    ErrorMessage.TRANSACTION_PENDING.value,
+                    data = {"tx_hash": receipt.hex()}).__dict__()
+        except Exception as e:
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.TRANSACTION_NOT_CANCELLED.value, str(e).replace("\\", r"\\")).__dict__()
+
+    def retry_transaction(self, tx_hash: str) -> Any:
+        try:
+            try:
+                receipt = self.w3.eth.get_transaction_receipt(tx_hash)
+                data = { "tx_hash": receipt["transactionHash"].hex() }
+                return Response(StatusCode.ALREADY_EXISTS.value, StatusCode.TRANSACTION_EXISTS.value, ErrorMessage.TRANSACTION_EXISTS.value, data=data).__dict__()
+            except:
+                pass
+
+            func_name, func_params, nonce  = self.db.get(tx_hash)
+            func = self.manager_contract.find_functions_by_name(func_name)[0](*func_params)
+            tx_params = self._get_retry_tx_params(nonce)
+            receipt = self._build_and_send_tx(func, tx_params)
+
+            tx = None
+            try:
+                tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+                result = {
+                    "tx_hash": tx["transactionHash"].hex(),
+                    "gas_fees": tx["gasUsed"],
+                    }
+                if self.db.exists(tx_hash):
+                    self.db.rem(tx_hash)
+                    self.db.dump() # delete the pendig tx entry
+                return Response(StatusCode.OK.value, None, None, data=result).__dict__()
+            except TimeExhausted as te:
+                return TransactionTimedOut(
+                    StatusCode.REQUEST_TIMEOUT.value,
+                    StatusCode.TRANSACTION_PENDING.value,
+                    ErrorMessage.TRANSACTION_PENDING.value,
+                    data = {"tx_hash": receipt.hex()}).__dict__()
+
+        except Exception as e:
+            return TransactionFailedError(StatusCode.FAILED_TRANSACTION.value, StatusCode.RETRY_FAILED.value, str(e).replace("\\", r"\\")).__dict__()
+
+    def get_transaction_status(self, tx_hash: str) -> Any:
+        try:
+            receipt = self.w3.eth.get_transaction_receipt(tx_hash)
+            result = {
+                "tx_hash": receipt["transactionHash"].hex(),
+                "gas_fees": receipt["gasUsed"],
+                "block_number": receipt["blockNumber"],
+                "status": receipt["status"]
+            }
+            return Response(StatusCode.OK.value, None, None, data=result).__dict__()
+        except Exception as e:
+            return TransactionFailedError(StatusCode.NOT_FOUND.value, StatusCode.TRANSACTION_NOT_FOUND.value, ErrorMessage.TRANSACTION_NOT_FOUND.value).__dict__()
 
     def check_trade_constraints(self, amm: str, dir: str, quoteAssetAmount: int, leverage: int, slippage: int) -> Any:
         try:
@@ -1112,11 +1251,20 @@ class Polysynth:
         tx_params = self._get_tx_params()
         func = stable_token.mintFake()
         receipt = self._build_and_send_tx(func, tx_params)
-        tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=1000)
-        time.sleep(1)        
+        tx = None
+        try:
+            tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=self.tx_timeout)
+        except TimeExhausted as te:
+            self.db.set(receipt.hex(), (func, tx_params["nonce"]))
+            self.db.dump()
+            return TransactionTimedOut(
+                StatusCode.REQUEST_TIMEOUT.value,
+                StatusCode.TRANSACTION_PENDING.value,
+                ErrorMessage.TRANSACTION_PENDING.value,
+                data = {"tx_hash": receipt.hex()})
     
     def _build_and_send_tx(
-        self, function: ContractFunction, tx_params: Optional[TxParams] = None
+        self, function: Optional[ContractFunction], tx_params: Optional[TxParams] = None
     ) -> HexBytes:
         """Build and send a transaction."""
         if not tx_params:
@@ -1144,3 +1292,31 @@ class Polysynth:
             ),
             "chainId": int(self.w3.net.version),
         }
+
+    def _get_cancel_tx_params(self, value: Wei = Wei(0), gas: Wei = Wei(5000000)) -> TxParams:
+        """Get generic transaction parameters."""
+        gasFee = _estimate_gas_fee("standard", self.network)
+        return {
+            "from": _addr_to_str(self.address),
+            "to": "0x0000000000000000000000000000000000000000",
+            "value": "0x0",
+            "gas": gas,
+            "maxFeePerGas": Web3.toWei(gasFee['maxFee'], 'gwei'),
+            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee'], 'gwei'),
+            "nonce": max(
+                self.last_nonce, self.w3.eth.get_transaction_count(self.address)
+            ),
+            "chainId": int(self.w3.net.version),
+        }
+
+    def _get_retry_tx_params(self, nonce: int, value: Wei = Wei(0), gas: Wei = Wei(5000000)) -> TxParams:
+        """Get generic transaction parameters."""
+        gasFee = _estimate_gas_fee("standard", self.network)
+        return {
+            "from": _addr_to_str(self.address),
+            "value": value,
+            "maxFeePerGas": Web3.toWei(gasFee['maxFee'], 'gwei'),
+            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee'], 'gwei'),
+            "nonce": nonce,
+            "chainId": int(self.w3.net.version),
+        }
\ No newline at end of file
